/* Bookmark dropdown */
var timeout = 500,
    timeouts = [],
    closetimer = 0,
    bookmarkmenuitem = 0,
    // A crude generalised checked for the console...
    consoleOK = ($.browser.msie ? false : true);

/**
 * Close extra share options
 */
function bookmarkmenu_close() {
    if (bookmarkmenuitem) {
        bookmarkmenuitem.removeClass("showSoMe").addClass("hideSoMe");
    }
}

/**
 * Create timer for extra share options
 */
function bookmarkmenu_timer() {
    closetimer = window.setTimeout(bookmarkmenu_close, timeout);
}

/**
 * Cancel timer for extra share options
 */
function bookmarkmenu_canceltimer() {
    if (closetimer) {
        window.clearTimeout(closetimer);
        closetimer = null;
    }
}

/**
 * Open extra share options
 */
function bookmarkmenu_open() {
    bookmarkmenu_canceltimer();
    bookmarkmenu_close();
    bookmarkmenuitem = $(this).find(".moreshareoptions").removeClass("hideSoMe").addClass("showSoMe");
}

/**
 * Extracts data from the table of data
 *
 * @param {jQuery object} table     Table containing relevant data
 *
 */
function extractDataFromTable(table) {
    var lineData = [];
    table.find("tbody tr").each(function(index) {
        // $(this) is used more than once; cache it for performance.
        var $row = $(this);
        var rowData = [];
        // APPEND the individual pieces of data
        // Be aware that we need to force the type of the count
        // otherwise jqplot fails...
        rowData.push($row.find(":nth-child(1)").text());
        rowData.push(+$row.find(":nth-child(2)").text());
        // PREPEND each set of data...
        lineData.unshift(rowData);
    });
    return lineData;
}

/**
 * Plots graphs for metrics (pie and line only)
 *
 * @param {string} gtype    graph type: pie|other (actually 'line')
 * @param {string} target   id to which to attach output
 * @param {object} data     data to graph
 *
 */
function plotGraph(gType, target, data) {
    var plotOptions = {};

    switch (gType) {
    case "pie":
        var total = 0;
        $(data).map(function() {
            total += this[1];
        });
        var pieLabels = $.makeArray($(data).map(function() {return this[0] + " (" + Math.round((this[1] * 100) / total) + "%)"; }));

        plotOptions = {
            // Define colours to use...
            seriesColors: ["#1a6594", "#f0bd68", "#d6caa5"],
            // Define various overall defaults
            seriesDefaults: {
                renderer: $.jqplot.PieRenderer,
                rendererOptions: {
                    dataLabels: pieLabels,
                    dataLabelPositionFactor: 0.75,
                    highlightMouseDown: false,
                    highlightMouseOver: false,
                    showDataLabels: true,
                    sliceMargin: 10
                }
            }
        };
        break;
    default:
        plotOptions = {
            // Define colours to use...
            seriesColors: ["#1a6594", "#f0bd68", "#d6caa5"],
            // Define various other overall defaults
            seriesDefaults: {
                shadow: false,
                showMarker: false
            },
            // Define the defaults for both axes
            axesDefaults: {
                tickRenderer: $.jqplot.CanvasAxisTickRenderer,
                tickOptions: {
                    fontSize: "10pt"
                }
            },
            // Define specific properties for the X axis
            // tickInterval = 60 * 60 * 24 * 30 * 1000
            // (milliseconds in 30 days)...
            axes: {
                xaxis: {
                    renderer: $.jqplot.DateAxisRenderer,
                    tickInterval: "2592000000",
                    tickOptions: {
                        angle: -90,
                        formatString: "%b - %Y  "
                    }
                },
                yaxis: {
                    min: 0,
                    tickOptions: {
                        formatString: "%7d  "
                    }
                }
            },
            highlighter: {
                show: true,
                sizeAdjust: 10
            },
            cursor: {
                show: false
            }
        };
        break;
    }

    var graph = $.jqplot(target, [data], plotOptions);

}

/**
 * Changes the direction of the chevrons
 *
 * @param {jQuery object} here          Current location
 * @param {string}        direction     Direction of arrow (down | up)
 *
 */
function changeChevronDirection(here, direction) {
    switch (direction) {
    case "down":
        here.removeClass("down")
            .addClass("up")
            .find("img")
            .attr("src", "/images/aip/chevron_up.gif");
        break;
    case "up":
        here.removeClass("up")
            .addClass("down")
            .find("img")
            .attr("src", "/images/aip/chevron_down.gif");
        break;
    default:
        break;
    }
}

var findChevronContent = function(obj) {
    return $(obj).siblings(".chevroncontent").add($(obj).parent().siblings(".chevroncontent"));
};

// Declare some default dialog attributes
var stdDialogOptions = {
    autoOpen: false,
    height: 640,
    width: 480,
    modal: true,
    resizable: true,
    position: {
        my: "center",
        at: "center",
        of: $(window)
    }
};

/**
 * Checks for no search term entered
 *
 * This has now been extended to ensure that AT LEAST one of the following is submitted:
 *
 * 1. Search term
 * 2. Title
 * 3. Author
 * 4. ISSN/ISBN/DOI
 *
 * @param {object} e Event
 *
 */

function checkSearchTermBlank(e) {
    // Get values of various term fields
    var searchField = $("#value1"),
        searchTerm = searchField.val(),
        titleTerm = $("#value2").val(),
        authorTerm = $("#value3").val(),
        doiTerm = $("#value4").val(),
        blankMsg = $("#blank_search_term_label").text();
    // If ALL are blank then stops submission, alerts user, focus on search term field
    if (!searchTerm && !titleTerm && !authorTerm && !doiTerm) {
        e.stopImmediatePropagation();
        e.preventDefault();
        alert(blankMsg);
        searchField.focus();
    }
}

/**
 * Insert DeepDyve link
 *
 * @param {string} type            The type of link (button | text)
 * @param {string} insertionPoint  The class to which to attach the link
 *
 */
function insertDeepDyveLink(type, insertionPoint) {
    //
    // if (consoleOK) {console.info("insertDeepDyveLink() parameters:\n1. insertionPoint: " + insertionPoint);}
    //
    var currency,
        DDoi = $(insertionPoint).text(),
        DDUrl = "http://www.deepdyve.com/rental-link?fieldName=journal_doi&docId=" + DDoi + "&key=AIP&affiliateId=AIP&format=jsonp&callback=?",
        newHtml,
        rentLabel1 = $(".rent_button_label1").first().text(),
        rentLabel2 = $(".rent_button_label2").first().text();

    $.getJSON(DDUrl, function(data) {
        if (data.status === "ok") {
            currency = "$";
            newHtml = "";
            if (type === "button") {
                newHtml += '<div class="access-options"><div class="rentItem">';
                newHtml += '<button type="button" class="rent-link externallink styledbutton" rel="external" href="' + data.url + '">';
                newHtml += rentLabel1 + '<span class="deepdyveprice">';
                if (data.price !== null && data.price !== "") {
                    newHtml += currency +  data.price;
                }
                newHtml += "</span></button></div></div>";
            } else {
                newHtml += '<div class="rent-link-text">';
                newHtml += '<a class="rent-link-text externallink" rel="external" href="' + data.url + '">';
                newHtml += rentLabel2 + '<span class="deepdyveprice">';
                if (data.price !== null && data.price !== "") {
                    newHtml += currency + data.price;
                }
                newHtml += '</span></a></div>';
            }
            $(insertionPoint).siblings(".access-options").after(newHtml);
        }
    });
}

/**
 * Creates link to DeepDyve (for all instances)
 *
 * @param {string} type            The type of link (button | text)
 *
 */
function createDeepDyve(type) {
    $(".deepdyve").each(function () {
        var deepdyveDOI = $(this);
        insertDeepDyveLink(type, deepdyveDOI);
    });
}

/**
 * Display metrics data as a table (normally following a failure with plotting)
 *
 * @param {string} tableName
 * @param {string} graphName
 * @param {string} eMsg
 */
function displayTabularMetrics(tableName, graphName, eMsg) {
    var currTable = $("#" + tableName);
    currTable.before(eMsg);
    currTable.find("tbody .metricDate").each(function(index) {
        var currItem = $(this),
            dateStr = currItem.text(),
            mDate = new Date(dateStr.substr(0, 10));
        currItem.text(mDate.toDateString());
    });
    currTable.find(".metricDate, .totalCount").addClass("metricsErrorDesc");
    currTable.find(".metricCount").addClass("metricsErrorCount");
    currTable.addClass("metricsErrorTable");
    $("#" + graphName).addClass("hideMe");
}

/**
 * Sends a siq tagging request
 */
function siq(siqUrl, webId, pageTitle, doi, eventType, logPub2webEvent, searchTerm, callback) {

    if (!searchTerm) {
        searchTerm = "";
    }

    var data = {
            itemId: webId,
            pageTitle: pageTitle,
            doi: doi,
            eventType: eventType,
            logPub2webEvent: logPub2webEvent,
            searchTerm: searchTerm
    };
    // A load is required rather than get for the script element to be run by the browser - similarly no suffixed selector is permitted
    $("#siqResponse").load(siqUrl, data, function(contents){
        if (callback) {
            callback(contents);
        }
    });
}

/**
 * Chop up a url into parameters...
 *
 *  @param {string} _url
 */
function getUrlVars(_url) {
    var vars = [], i, hash,
        hashes = _url.slice(_url.indexOf('?') + 1).split('&');
    for (i = 0; i < hashes.length; i++) {
        hash = hashes[i].split('=');
        vars.push(hash[0]);
        vars[hash[0]] = hash[1];
    }
    return vars;
}

/**
 * Checks for the appearance of the MORE links in Related tab...
 */
function checkRelatedTabChange() {
    var loop,
        moreLinkHtml = "",
        target;

    target = "#morelikethis .morelink";
    moreLinkHtml += "<a href='#' title='' class='more std-display'><img src='/images/aip/plus_icon.gif' alt='+' /> More</a>";
    moreLinkHtml += "<a href='#' title='' class='less std-display hidden'><img src='/images/aip/minus_icon.gif' alt='-' /> Less</a>";
    if ($(target).length) {
        for (loop = 0; loop < timeouts.length; loop++) {
            clearTimeout(loop);
        }
        $("#morelikethis .morelink").html(moreLinkHtml);
    } else {
        // call the function again after default milliseconds
        timeouts.push(setTimeout(checkRelatedTabChange, timeout));
    }
}

jQuery.cachedScript = function(url, options) {
    // allow user to set any option except for dataType, cache, and url
    options = $.extend(options || {}, {
        dataType: "script",
        cache: true,
        url: url
    });
    // Use $.ajax() since it is more flexible than $.getScript
    // Return the jqXHR object so we can chain callbacks
    return jQuery.ajax(options);
};

// ONLOAD ACTIONS
$(document).ready(function() {

    /* Issue due to ahah call so not being bound so applied a click to Export Citations as live/on
       don't work with toggle so changed slightly. BUG 45783 */

    $("a.toggle").live("click",function(e) {
        var $this = $(this);
        if ($this.hasClass("expanded")) {
            findToggleContent($this).slideUp(function() {
                $this.removeClass("expanded");
                $this.blur();
            });
        } else {
            findToggleContent($this).slideDown();
            $this.addClass("expanded");
        }
        e.preventDefault();
    });

    /* This has been brought in from jp site.js as weird close all descriptions on Physics Today tab for some reason needed
       to go up an extra parent to close even tho its not needed to open.  further investigation is required but works */

    $(".plus").live("click", function(){
        var here = $(this);
        here.parent().find(".minus").show();
        here.hide();
        here.parent().parent().find(".description").slideDown();
    });

    $(".minus").live("click", function(){
        var here = $(this);
        here.parent().find(".plus").show();
        here.parent().parent().parent().find(".plus").show();
        here.parent().parent().parent().find(".minus").hide();
        here.hide();
        here.parent().parent().parent().find(".description").slideUp();
    });

    var hiddenContext = $("#hiddenContext").text();

    var statsurlwrapper  = hiddenContext + "/statslogwrapper",
        statsurlredirect = hiddenContext + "/statslogredirect";

    var siqUrl = hiddenContext + "/siq/siq.action";

    // Create a deepdyve article rent link if it is necessary
    if (($(".deepdyve").length > 0) && ($(".rentItem").length === 0)) {

        if ($("div.itemInCart").length > 0) {
            // if person already added to cart show text link instead of button
            createDeepDyve("text");
        } else {
            // show rent button
            createDeepDyve("button");
        }
    }

    if ($("#customwebform").length > 0) {
        var token = $("#cFGeneratedToken").text(),
            text = $("#cFTokenString").text(),
            tokenCF = $("<input>").attr({"type": "hidden", "name": "hashText"}).val(text),
            tokenTextCF = $("<input>").attr({"type": "hidden", "name": "hashToken"}).val(token);

        $("#customwebform").append($(tokenCF));
        $("#customwebform").append($(tokenTextCF));
    }

    // Custom web form validation
    $("#customwebform").validate();

    // Advanced search check if term blank
    $("form#advanced-search-form").submit(function(e) {
        checkSearchTermBlank(e);
    });

    // Replace all broken images with placeholder images
    $("img.cover").error(function () {
        $(this).unbind("error").attr("src", "/images/aip/placeholder-image.jpg");
    });

    $("img.urlnotprovided").attr("src", "/images/aip/placeholder-image.jpg");

    $(".viewfurthershareoptions").hover(
        bookmarkmenu_open,
        bookmarkmenu_timer
    );

    $(".viewfurthershareoptions img").click(bookmarkmenu_open);

    // Send the user to the signin...
    $(".institutionalusermsg .signinlink").live("click", function(e) {
        $(".item-signin .signinlink").trigger("click");
    });

    $(".chevron.down").live("click", function(e) {
        findChevronContent(this).slideDown();
        var here = $(this);
        changeChevronDirection(here, "down");
        if (here.hasClass("signinlink")) {
            $("#signname").focus();
        }
        return false;
    });

    // adding to support functionality described to client - native highlighting to chrome but not other browsers
    $("#signinform input[type='text'], #signinform input[type='password']").focus(function () {
        $(this).removeClass("pwbox-normal").addClass("pwbox-highlight");
    });

    $("#signinform input[type='text'], #signinform input[type='password']").blur(function () {
        $(this).removeClass("pwbox-highlight").addClass("pwbox-normal");
    });

    $(".chevron.up").live("click", function(e) {
        findChevronContent(this).slideUp();
        var here = $(this);
        changeChevronDirection(here, "up");
        return false;
    });

    $("#exportbutton").click(function(e) {
        var anchor = $("#exportselect");
        if (anchor.val() !== "") {
            window.location = anchor.val();
        }
        return false;
    });

    // for 'reprints & permissions' link in the sidebar, Use a pop-up window rather than a full window...
    $(".item-reprint a.popup").click(function(e) {
        window.open((this.href + "?url=" + window.location.href), "Rightslink", "location=no,toolbar=no,directories=no,status=no,menubar=no,scrollbars=yes,resizable=yes,width=700,height=600");
        return false;
    });

    $("div.authorsWithPopup span.meta-value.authors a").live("click", function(e) {
        // Kills the intuitive behavior of link - replaces with popup dialog
        e.preventDefault();

        var here = $(this);
        var aDialog = $("#authorpopup");

        $(".authorpopupwrapper").remove();

        aDialog.find(".popuptext").remove();

        var dHeight = 170,
            dWidth = 200,
            authorName = here.text(),
            authorNamePrefix = "",
            authorNameSuffix = "",
            authorNameForPubMedSearch = authorName,
            offset = 50,
            popuptext = "",
            posX = 0,
            posY = 0,
            title = "";

        // Find the related links...
        var scitationLink = here.parents(".authorsWithPopup").siblings(".scitationSearch").html(),
            pubmedLink    = here.parents(".authorsWithPopup").siblings(".pubmedSearch").html(),
            scholarLink   = here.parents(".authorsWithPopup").siblings(".scholarSearch").html(),
            option12      = "&option12=resultCategory&value12=ResearchPublicationContent";


        if (here.attr("class") === "nonDisambigAuthorLink") {
           scitationLink = scitationLink.replace("##AUTHORLINK##", here.attr("href") + option12);
        } else {
           scitationLink = scitationLink.replace("##AUTHORLINK##", here.attr("href"));
        }

        if (authorName.indexOf(". ") > 0) {
            // Bug 37062 - Pubmed search has data loaded differently to the Pub2web.
            // The results come back more reliably if we put the Initials at the end of the last name.
            authorNamePrefix = authorName;
            authorNamePrefix = authorNamePrefix.substring(0, authorNamePrefix.indexOf(". "));

            authorNameSuffix = authorName.substring(authorName.indexOf(". ") + 2);
            authorNameForPubMedSearch = authorNamePrefix + " " + authorNameSuffix;
        }

        pubmedLink = pubmedLink.replace("##AUTHORNAME##", authorNameForPubMedSearch);

        scholarLink = scholarLink.replace("##AUTHORNAME##", authorName);
        scholarLink = scholarLink.replace(/&amp;amp;quot;/g, "&quot;");

        popuptext = "<div class=\"popuptext\">" +
                    "<div class=\"popup-link\">" + scitationLink + "</div>" +
                    "<div class=\"popup-link\">" + pubmedLink + "</div>" +
                    "<div class=\"popup-link popup-link-last\">" + scholarLink + "</div>" +
                    "</div>";

        title ="<div class=\"popup-header\">More content by<br/><div class=\"authorname-in-popup\">" + authorName + "</div></div>";
        posX = here.offset().left - $(document).scrollLeft() - offset + here.outerWidth();
        posY = here.offset().top  - $(document).scrollTop()  + here.outerHeight();

        aDialog.dialog({
            title: title,
            height: dHeight,
            width: dWidth,
            position: [posX, posY],
            modal: false,
            autoOpen: false
        });
        aDialog.dialog().parent(".ui-dialog").wrap("<div class='authorpopupwrapper'></div>");

        aDialog.dialog("open");
        aDialog.append(popuptext);
        return false;
    });

    $(".addAlertLink").click(function(e) {
        var source = e.target;
        // To propagate the event in case of blurb-editor image is clicked
        if ($(source).is("img")) {
            return true;
        }
        var parent = $(this).closest("li"),
            alertContext = parent.find(".alertContext").text(),
            alertContextTitle = parent.find(".alertContextTitle").text(),
            alertContentId = parent.find(".alertContentId").text(),
            submitUrl = parent.find(".submitUrl").text(),
            frequencyKeyName = "freq:" + alertContentId,
            data = {
                alertContext: alertContext,
                alertDescription: alertContextTitle,
                update: "true",
                alertScopeObjectId: alertContentId,
                alertFrequency: "HOUR",
                enabledKeyName: "on"
            },
            temp = data.enabledKeyName,
            isContentAlertType = alertContext.match("citation|correction") !== null ? true : false;

        if (isContentAlertType) {
            data.contentAlert = temp;
        } else {
            data["enabled:" + alertContentId] = temp;
        }

        // delete data.enabledKeyName;

        $.post(submitUrl, data, function(resp) {
            parent.find("span.addAlertLinkCont").addClass("hiddenElement");
            parent.find(".successMessage").removeClass("hiddenElement");
        });

        return false;
    });

    $(".alertLink").click(function(e) {
        $("#alertForm").submit();
        return false;
    });

    // Functions for hiding and showing latest articles on journal homepage

    // The selector is complicated because lower-level items also have the 'ul.togglecontent' structure,
    // which we do not want to have to deal with...

    $("#journal .toc .publistwrapper ul.togglecontent > li").not(".articleMetadata ul.togglecontent > li").each(function (index) {
        var here = $(this);
        if (here.is(".odd, .even")) {
            here.removeClass("initialHide");
            // Hide if more than 5 (zero-based index) in list...
            if (index > 4) {
                here.addClass("initialHide");
            }
        }
    });

    $("#journal .showOtherLatestArticles a.moreLink2").live("click", function(e) {
        var here = $(this);
        e.stopImmediatePropagation();
        e.preventDefault();
        here.parent().siblings(".publistwrapper").find("li.initialHide").show();
        here.hide();
        here.siblings(".lessLink2").show();
    });

    $("#journal .showOtherLatestArticles a.lessLink2").live("click", function(e) {
        var here = $(this);
        e.stopImmediatePropagation();
        e.preventDefault();
        here.parent().siblings(".publistwrapper").find("li.initialHide").hide();
        here.hide();
        here.siblings(".moreLink2").show();
    });

    $("#standardscontainer .showOtherLatestStandards a.moreLink2").live("click", function(e) {
        var here = $(this);
        e.stopImmediatePropagation();
        e.preventDefault();
        here.parent().siblings("ul.flat").find("li.initialHide").show();
        here.hide();
        here.siblings(".lessLink2").show();
    });

    $("#standardscontainer .showOtherLatestStandards a.lessLink2").live("click", function(e) {
        var here = $(this);
        e.stopImmediatePropagation();
        e.preventDefault();
        here.parent().siblings("ul.flat").find("li.initialHide").hide();
        here.hide();
        here.siblings(".moreLink2").show();
    });

    var moreLinkHtml = "";
    moreLinkHtml += "<a href='#' title='Link to more items in list' class='showmore std-display'><img src='/images/aip/plus_icon.gif' alt='+' /> More</a>";
    moreLinkHtml += "<a href='#' title='Hide items in list' class='facethidetext std-display'><img src='/images/aip/minus_icon.gif' alt='-' /> Less</a>";

    var moreImageHtml = "<img src='/images/aip/plus_icon.gif' alt='+' /> More",
        lessImageHtml = "<img src='/images/aip/minus_icon.gif' alt='-' /> Less";

    // Set the +MORE for more like this, overriding J-P
    $(".seeMoreFacetsLink").html(moreLinkHtml);

    // Check to see if the Realted tab is loaded or not...
    checkRelatedTabChange();

    $("#mostviewed .morelink").live("click", function(e) {
        var here = $(this);
        here.parent().parent().find(".hide").show();
        here.addClass("hideMoreCited").html(lessImageHtml).css({"background-image":"none"});
        here.show();
        return false;
    });

    $("#mostviewed .hideMoreCited").live("click", function(e) {
        var here = $(this);
        here.parent().parent().find(".hide").hide();
        here.removeClass("hideMoreCited").html(moreImageHtml).css({"background-image":"none"});
        here.show();
        return false;
    });

    $("a.moreLink").live("click", function(e) {
        var here = $(this);
        e.stopImmediatePropagation();
        e.preventDefault();
        here.siblings("ul").find("li.hide").show();
        here.hide();
        here.siblings(".lessLink").show();
    });

    $("a.lessLink").live("click", function(e) {
        var here = $(this);
        e.stopImmediatePropagation();
        e.preventDefault();
        here.siblings("ul").find("li.hide").hide();
        here.hide();
        here.siblings(".moreLink").show();
    });

    $(".seeMoreFacetsLink a").live("click", function(e) {
        var here = $(this);
        e.preventDefault();
        here.closest("ul").find(".hidden").show();
        here.next("a").show();
        here.hide();
    });

    $(".seeMoreFacetsLink .facethidetext").live("click", function(e) {
        var here = $(this);
        e.preventDefault();
        here.closest("ul").find(".hidden").hide();
        here.prev("a").show();
        here.hide();
    });

    $(".toggleajaxfacetitem .facethidetext").live("click", function(e) {
        var here = $(this),
            hereList = here.closest("ul");
        e.preventDefault();
        hereList.find(".ajaxhidden").hide();
        hereList.find(".seeAhahFacetsLink").show();
        hereList.find(".seeAhahFacetsLink .showmore").show();
        hereList.find(".showmore").removeClass("cursorWait").addClass("cursorPointer");
        here.closest("ul").find("a.facethidetext").hide();
        hereList.find(".toggleajaxfacetitem").remove();
    });

    // Display/Hide dropdown menu for PTOL Daily Edition
    $("li#ptol_dailyeditiontab").mouseenter(function (e) {
        $("#megamenu").show(250);
    });

    $("#content, #sidebar_right, #ptol_banner, #ptol_abouttab, #ptol_printeditiontab, #ptol_jobstab, #ptol_hometab").mouseenter(function (e) {
        $("#megamenu").hide(100);
    });

    // Display/Hide dropdown menu for Publishers
    $(".navChevron").click(function(){
        var $this = $(this);
        if ($this.hasClass("chevronUp")) {
            $this.removeClass("chevronUp");
            $this.attr("title", "View Publishers List");
        } else {
            $(this).addClass("chevronUp");
            $this.attr("title", "Close Publishers List");
        }
        $("#megamenu_pub").toggle();
    });

    //
    // In various places we need a little dialog box which is attached to
    //   a class rather than an id.
    //
    // So far the search up 2 levels from the point of invocation works...
    //
    $(".signInOrRegister").live("click", function(e) {
        var here = $(this);
        var dialogHook = $("#signInOrRegisterDialog");
        if (dialogHook !== null) {
            dialogHook.dialog({
                autoOpen: false,
                height: 125,
                width: 200,
                modal: false,
                resizable: true
            });
            dialogHook.find(".dialogText").remove();

            dialogHook.dialog().parent(".ui-dialog").wrap("<div class=\"signInOrRegisterWrapper\"></div>");
            dialogHook.dialog("open");
            dialogHook.dialog("option", "position", {my: "left top", at: "left bottom", of: here});

            dialogHook.append("<h2 class=\"dialogText\">Sign in or Register</h2>");
            dialogHook.append("<span class=\"dialogText\">Please sign in or register to use this feature</span>");
        }
        return false;
    });

    $(".completeProfile").click(function(e) {
        var here = $(this);
        var dialogHook = $("#signInOrRegisterDialog");
        if (dialogHook !== null) {
            dialogHook.dialog({
                autoOpen: false,
                height: 125,
                width: 200,
                modal: false,
                resizable: true
            });
            dialogHook.find(".dialogText").remove();

            dialogHook.dialog().parent(".ui-dialog").wrap("<div class=\"signInOrRegisterWrapper\"></div>");
            dialogHook.dialog("open");
            dialogHook.dialog("option", "position", {my: "left top", at: "left bottom", of: here});

            dialogHook.append("<h2 class=\"dialogText\">Complete your profile</h2>");
            dialogHook.append("<span class=\"dialogText\">Please complete your profile to use this feature</span>");
        }
        return false;
    });

    $(".moreSearchDetails").click(function (e) {

        var sDialog = $("#searchExplanationTextDialogDisplay");

        sDialog.find(".searchTermDisplayDialog").remove();
        var searchTermText = $(".searchExplanationTextDialogHiddenDisplay").html();

        var dWidth = 700;
        var dHeight = 376;
        sDialog.dialog({
            height: dHeight,
            width: dWidth,
            modal: false,
            autoOpen: false
        });
        sDialog.append("<div class='searchTermDisplayDialog'>" + searchTermText + "</div>");
        sDialog.dialog().parent(".ui-dialog").wrap("<div class='searchExplanationTextDisplayWrapper'></div>");
        sDialog.dialog("open");
        sDialog.show();

        return false;
    });

    // Change requested by AIP to show exact phrase by default
    $('select#booleanselector option[value="searchoptionexact"]').attr("selected", "selected");

    if ($(".bookmarkcontainer").length > 0) {
        var bibsonomyUrl = "http://www.bibsonomy.org/ShowBookmarkEntry?url={u}&description={t}",
            citeulikeUrl,
            doiURL,
            here,
            newRE1,
            newRE2,
            newTitle,
            newUrl,
            startPoint,
            target;

        if (aipProps.currentPage === 'home.markedlists') {
            $(".sharelinks").mouseover(function(e) {
                target = $(this);
                startPoint = target.closest(".resultItem");
                doiURL = startPoint.find("span.doi a").attr("href");
                newRE1 = new RegExp("<[^>]*>", "g");
                newRE2 = new RegExp("  *", "g");
                newTitle = startPoint.find(".title a").text();
                newTitle = newTitle.replace(newRE1, "");
                newTitle = newTitle.replace(newRE2, " ");
                newUrl = window.location.protocol + "//" + window.location.host + startPoint.find(".title a").attr("href");
                citeulikeUrl = "http://www.citeulike.org/posturl?username=&bml=popup&url=" + encodeURI(doiURL) + "&title={t}";

                $.bookmark.addSite("bibsonomy", "Bibsonomy", "/images/aip/bibsonomy.png", "en", "other", bibsonomyUrl);
                $.bookmark.addSite("citeulike", "CiteULike", "/images/aip/citeulike.png", "en", "other", citeulikeUrl);

                target.find(".moreshareoptions").bookmark({
                    url: newUrl,
                    title: newTitle,
                    icons: "/images/jp/bookmarks.png",
                    sites: ["bibsonomy", "citeulike", "digg", "delicious", "google", "linkedin"]
                });

                target.find(".moreshareoptions").show();

            });

            $(".sharelinks").mouseout(function(e) {
                $(this).find(".moreshareoptions").hide();
            });
        } else {
            doiURL = $("span.doi a").attr("href");
            bibsonomyUrl = "http://www.bibsonomy.org/ShowBookmarkEntry?url={u}&description={t}";
            citeulikeUrl = "http://www.citeulike.org/posturl?username=&bml=popup&url=" + encodeURI(doiURL) + "&title={t}";

            $.bookmark.addSite("bibsonomy", "Bibsonomy", "/images/aip/bibsonomy.png", "en", "other", bibsonomyUrl);
            $.bookmark.addSite("citeulike", "CiteULike", "/images/aip/citeulike.png", "en", "other", citeulikeUrl);

            $(".moreshareoptions").bookmark({
                icons: "/images/jp/bookmarks.png",
                sites: ["bibsonomy", "citeulike", "digg", "delicious", "google", "linkedin"]
            });

            $(".sharelinks").mouseover(function(e) {
                $(this).find(".moreshareoptions").show();
            }).mouseout(function(e) {
                $(this).find(".moreshareoptions").hide();
            });
        }
    }

    // Marker for "Log in in to see this feature"
    $(".tabset .disabled").each(function(index) {
        var here = $(this),
            hasSubscription = here.closest("div").hasClass("uli"),
            newMsg = "",
            newTitle = "",
            noData = here.hasClass("nodata"),
            noAccess = here.hasClass("noaccess"),
            notLoggedIn = here.closest("div").hasClass("uli") ? false : true,
            msg0 = $("#tab_title_msg0").text() || "No data available.",
            msg1 = $("#tab_title_msg1").text() || "Please log in to see this content.",
            msg2 = $("#tab_title_msg2").text() || "You have no subscription access to this content.",
            title = here.attr("title");

        if (noData) {
            newMsg = msg0;
        } else if (noAccess) {
            if (notLoggedIn) {
                newMsg = msg1;
            } else {
                newMsg = msg2;
            }
        } else {
            newMsg = msg0;
        }

        newTitle = (title ? title + " - " + newMsg : newMsg);
        here.attr("title", newTitle);
    });

    // Marker for NOT YET IMPLEMENTED
    $("a[href='/mock/notimplemented'], a[href='/pub2web/mock/notimplemented']").each(function(index) {
        var here = $(this),
            title = here.attr("title"),
            newTitle = "",
            msg1 = "FUNCTIONALITY NOT YET IMPLEMENTED";

        if (title === "") {
            newTitle = msg1;
        } else {
            newTitle = title + " - " + msg1;
        }
        here.attr("title", newTitle);
    });

    $("#volumepage-search-form").one("submit", function(e) {
        var term = "",
            publicationStr = "";

        $("#searchpublication option:selected").each(function (index) {
            publicationStr += this.id + ",";
        });
        publicationStr = publicationStr.slice(0, publicationStr.length - 1);

        $.get(statsurlwrapper, {searchterm: term, publicationids: publicationStr}, function(contents){
            $.post(statsurlredirect, {statsLogContents: contents}, function() {
                $("#volumepage-search-form").submit();
            });
        });
        return false;
    });

    // AHAH call for comments count - used for listing pages
    $(".replynodecommentcount").each(function(index) {

        var here = $(this),
            itemId = $("#hiddenitemid", here).text(),
            url = hiddenContext + "/commenting/comments/commentscount.action",
            data = {"itemId": itemId},
            fragment = "";

        $.ajax({
            type: "POST",
            url: url,
            data: data,
            datatype: "html",
            success: function(resp, statusText) {
                // The response is an entire page, so we need to extract
                // the bits we need...
                fragment = $(".commentsAhahCountContainer", resp);
            },
            error: function(req, statusText, message) {
                fragment = "<p>An error occurred while retrieving comments.</p>";
            },
            complete: function(req, statusText) {
                $(".commentscountloading", here).remove();
                here.after(fragment);
            }
        });
    });

    // AHAH call for metrics
    $("#metrics a").click(function(e) {
        var metricsContainer = $(".metricsContainer"),
            startDate = metricsContainer.find(".metricsPubDate").text(),
            endDate = metricsContainer.find(".metricsEndDate").text(),
            webId = metricsContainer.find(".metricsItemId").text(),
            url = hiddenContext + "/metrics/metrics.action?startDate=" + startDate + "&endDate=" + endDate + "&itemId=" + webId,
            ERR_MSG0 = "<p class='noMetricsData'>" + $("#metrics_msg0_label").text() + "</p>",
            ERR_MSG1 = "<p class='metricsMsg'>" + $("#metrics_msg1_label").text() + "</p>",
            ERR_MSG2 = "<p class='metricsMsg'>" + $("#metrics_msg2_label").text() + "</p>",
            pageTitle = $(".siqPageTitle").text(),
            doi = $(".siqDoi").text(),
            lineData1,
            lineData2,
            lineData3;

        // SIQ tagging request
        siq(siqUrl, webId, pageTitle, doi, "Metrics");

        if (metricsContainer.hasClass("retrieveMetrics")) {
            // Make the call...
            $.ajax({
                type: "GET",
                url: url,
                timeout: 90000,
                success: function(resp, statusText) {
                    metricsContainer.find(".metricsDetails").append(resp);
                    metricsContainer.removeClass("retrieveMetrics");
                },
                error: function(req, statusText, message) {
                    metricsContainer.find(".metricsDetails").html(ERR_MSG1).addClass("ajax-error");
                },
                complete: function(req, statusText) {
                    $(".itemMetricsLoading").remove();
                    var table1 = $("#abstractDayView"),
                        table1HasData = (table1.find("td").hasClass("noMetricsData") ? false : true),
                        table2 = $("#fulltextDayView"),
                        table2HasData = (table2.find("td").hasClass("noMetricsData") ? false : true),
                        table3 = $("#metricTotals"),
                        // Notice the negation...
                        table3HasData = (!table3.find("td").hasClass("noMetricsData") ? true : false);

                    // Plot data from Table 1...
                    if (table1HasData) {
                        lineData1 = extractDataFromTable(table1);
                        try {
                            plotGraph("line", "graph1Output", lineData1);
                        } catch (e) {
                            if (consoleOK) {console.log("graph1Output failed with: " + e.message);}
                            displayTabularMetrics("abstractDayView", "graph1Output", ERR_MSG2);
                        }
                    } else {
                        $("#graph1Output").append(ERR_MSG0);
                    }

                    // Plot data from Table 2...
                    if (table2HasData) {
                        lineData2 = extractDataFromTable(table2);
                        try {
                            plotGraph("line", "graph2Output", lineData2);
                        } catch (e) {
                            if (consoleOK) {console.log("graph2Output failed with: " + e.message);}
                            displayTabularMetrics("fulltextDayView", "graph2Output", ERR_MSG2);
                        }
                    } else {
                        $("#graph2Output").append(ERR_MSG0);
                    }

                    // Plot data from Table 3...
                    if (table3HasData) {
                        lineData3 = extractDataFromTable(table3);
                        try {
                            plotGraph("pie", "graph3Output", lineData3);
                        } catch (e) {
                            if (consoleOK) {console.log("graph3Output failed with: " + e.message);}
                            displayTabularMetrics("metricTotals", "graph3Output", ERR_MSG2);
                        }
                    }
                }
            });
        }
    });

    // Global SIQ variables
    var webId = $(".siqItemId").text(),
        pageTitle = $(".siqPageTitle").text(),
        doi = $(".siqDoi").text(),
        eventType = $(".siqPub2webEventType").text();

    // AHAH call for related tab required for SIQ tagging request
    $("#related a").click(function(e) {
        siq(siqUrl, webId, pageTitle, doi, "Related");
    });

    // AHAH call for references tab required for SIQ tagging request
    $("#references a").click(function(e) {
        var isActive = $(".siqReferencesTabEnabled").text();

        if (isActive) {
            siq(siqUrl, webId, pageTitle, doi, "References");
        }
    });

    // AHAH call for references tab required for SIQ tagging request
    $("#citations a").click(function(e) {
        var isActive = $(".siqCitationsTabEnabled").text();

        if (isActive) {
            siq(siqUrl, webId, pageTitle, doi, "Citations");
        }
        var itemId = $("#itemIdForCitations").text();
        var data = {
                "requesttype": "citations",
                "fmt": "ahah",
                "contentitem": itemId
            };

        var url = hiddenContext + "/content/citations";

        $.ajax({
            type: "GET",
            data: data,
            url: url,
            dataType: "html",
            success: function(resp, statusText) {
                $(".citingArticlesLoading").remove();
                if (resp !== null) {
                    $("#citationContent").get(0).innerHTML = resp;
                }
            },
            error: function(req, statusText, message) {
                $(".citingArticlesLoading").remove();
            }
        });
    });

    // AHAH call for abstract tab required for SIQ tagging request
    $("#abstract a").click(function(e) {
        siq(siqUrl, webId, pageTitle, doi, "Abstract", "true");
    });

    // AHAH call for data and media  tab required for SIQ tagging request
    $("#dataandmedia a").click(function(e) {
        siq(siqUrl, webId, pageTitle, doi, "DataAndMedia");
    });

    // AHAH call for PDF Full Text click required for SIQ tagging request
    $(".fulltext .pdf a").click(function(e) {
    	if (_gaq) {
    		_gaq.push(['_trackEvent', 'Download', 'PDF', this.href]);
    	}
        siq(siqUrl, webId, pageTitle, doi, "FulltextPDFDownload");
    });

    // SIQ tagging request for on load requests, i.e. not action related such as clicks
    siq(siqUrl, webId, pageTitle, doi, eventType);

    // The below unbinds the submit action within the jp site.js and instead we want to
    // to override with the one from the instance, which is below.
    $("#global-search-form").unbind("submit");

    //overriden submit action for quick search
    $("#global-search-form").one("submit", function() {
        var re1 = /(<([^>]+)>)/gi,
            term1 = $("#quickSearchBox").val(),
            term2 = term1.replace(re1, ""),
            pageTitle = $(".siqPageTitle").text();

        // Log siq event
        siq(siqUrl, webId, pageTitle, doi, "Search", null, term2, function(contents) {
            //log pub2web event
            $.get(statsurlwrapper, {searchterm: term2}, function(contents){
                $.post(statsurlredirect, {statsLogContents: contents}, function(){
                    $("#global-search-form").submit();
                });
            });
        });

        return false;

    });

    $("#sortRelevance").click(function(e) {
        e.preventDefault();
        $("#sortForm input").each(function() {
            var here = $(this);
            if ((here.attr("name") === "sortDescending") || (here.attr("name") === "sortField")) {
                here.remove();
            }
        });
        $("#sortForm").submit();
    });

    $("#sortOldest").click(function(e) {
        e.preventDefault();
        var sortForm = $("#sortForm");
        if ($("input[name=sortDescending]").size() === 0) {
            sortForm.append("<input type='hidden' name='sortDescending' value='false' />");
        } else {
            $("input[name=sortDescending]").val("false");
        }
        sortForm.append("<input type='hidden' name='sortField' value='prism_publicationDate' />");
        sortForm.submit();
    });

    $("#sortNewest").click(function(e) {
        e.preventDefault();
        var sortForm = $("#sortForm");
        if ($("input[name=sortDescending]").size() === 0) {
            sortForm.append("<input type='hidden' name='sortDescending' value='true' />");
        } else {
            $("input[name=sortDescending]").val("true");
        }
        sortForm.append("<input type='hidden' name='sortField' value='prism_publicationDate' />");
        sortForm.submit();
    });

    $(".markedList").click(function(e) {
        $("#markListForm").submit();
    });

    $(".seeAhahFacetsLink a").each(function(){
        $(this).unbind();
        $(this).click(function() {
            var here = $(this),
                ahahParent = here.parent(".seeAhahFacetsLink"),
                ahahGrdParent = ahahParent.parent("ul"),
                url = ahahGrdParent.find(".ahahurl").text(),
                ids = ahahGrdParent.find(".ahahids").text(),
                names = ahahGrdParent.find(".ahahnames").text(),
                values = ahahGrdParent.find(".ahahvalues").text(),
                searchUrl = ahahGrdParent.find(".ahahsearchurl").text(),
                data = {"ids": ids,
                    "names": names,
                    "values": values,
                    "searchurl": searchUrl
                };
            here.addClass("cursorWait");

            $.ajax({
                type: "POST",
                url: url,
                data: data,
                success: function(resp, statusText) {
                    ahahParent.after(resp);
                    var newHtml = "<a href='#' title='Hide items in list' class='facethidetext std-display'><img src='/images/aip/minus_icon.gif' alt='-' /> Less</a>";
                    $(".toggleajaxfacetitem").html(newHtml);
                    $(".toggleajaxfacetitem a").show();
                    ahahParent.hide();
                },
                error: function(req, statusText) {
                },
                complete: function(req, statusText) {
                    here.removeClass("cursorWait").addClass("cursorDefault");
                }
            });

            return false;
        });
    });

    if ($(".searchcompletetopic").size() > 0) {
        $(".searchcompletetopic").autocomplete({
            source: hiddenContext + "/search/autosuggest",
            minLength: 3,
            select: function(event, ui) {
                $(".searchcompletetopic").val(ui.item.label);
                $("#topic-search-form").submit();
            }
        });
    }

    $("#submitsearch").click(function(e) {
        checkSearchTermBlank(e);
    });

    $(".submit-parent-form").click(function(e) {
        var f = $(this).closest("form");
        if (f) {
            f.submit();
        }
    });

    // overwritting JP version PLUS additional code to hide extra data shown
    $("#morelikethis .morelink").live("click", function(e){
        var here = $(this),
            theLink = $(e.target);
        here.show(); //  JP versions hides the container so having to show it again.
        here.find("a").css({"display": "inline-block"});

        if (theLink.hasClass("more")) {
           theLink.hide();
           theLink.next().show();
           here.siblings("ul").find(".hide").show();

        } else {
           theLink.hide();
           theLink.prev().show();
           here.siblings("ul").find(".hide").hide();
        }

    });

    // Hide the Section Listing first time round...
    $(".sectionBar a.toggle").trigger("click");

    // Hide the entire comments section if commenting is disabled...
    $(".commentsDisabled").parents(".commentsContainer").hide();

    // If there is a slideshow, check that at least one rollover image is actually showing...
    if ($("#slideshow").size() > 0) {
        var slideShow = $("#slideshow");
        if (slideShow.find("li img.activeImage").size() === 0) {
            slideShow.find("li img").eq(0).addClass("activeImage");
        }
    }

    // Change the image display on rollover...
    $("#cyclenav li").mouseenter(function(e) {
        var here = $(this);
        here.siblings().removeClass("activeText");
        here.addClass("activeText");
        $("#slideshow").find("img").removeClass("activeImage").eq(here.index()).addClass("activeImage");
    });

    // Check on empty adverts and collapse the space...
    $(".advertRight1, .advertRight2, .advertRight3").each(function(index) {
        var here = $(this),
            emptyGif = /empty\.gif/,
            adHref = here.find("a").attr("href");
        if (emptyGif.test(adHref)) {
            here.addClass("hideMe");
        }
    });

    if (aipProps.currentSection === "ptol") {
        // Fetch list of all CSS stylesheets loaded...
        var cssCount = document.styleSheets.length,
            cssPtol = /ptol\.css/,
            loop,
            newCSS,
            ptolLoaded = false;
        for (loop = 0; loop < cssCount; loop++) {
            if (cssPtol.test(document.styleSheets[loop].href)) {
                ptolLoaded = true;
            }
        }
        // Load ptol.css if needed...
        if (!ptolLoaded) {
            if (consoleOK) {console.info("Loading PTOL CSS file...");}
            newCSS = document.createElement("link");
            newCSS.type = "text/css";
            newCSS.rel  = "stylesheet";
            newCSS.href = "/css/aip/ptol.css";
            document.getElementsByTagName("head")[0].appendChild(newCSS);
        }
    }

    // Hide the Print button if IE8 or IE9
    if ($(".printButton").size() > 0) {
        if ($.browser.msie) {
            $(".printButton").addClass("hideMe");
        }
    }

    // Replace the VIEW / HIDE controls on the 3rd party results page...
    if ($("#relatedDatabasesSearchResults").size() > 0) {
        var here1, here2, view, hide;

        $("#relatedDatabasesSearchResults").find(".resultItem").each(function(index) {
            here1 = $(this);
            here1.find(".showhide").addClass("std-display");
            here2 = here1.find(".plus");
            view = here2.html().replace("+", "<img alt=\"+\" src=\"/images/aip/plus_icon.gif\" />");
            here2.html(view);
            here2 = here1.find(".minus");
            hide = here2.html().replace("-", "<img alt=\"-\" src=\"/images/aip/minus_icon.gif\" />");
            here2.html(hide);
        });
    }

    $("a.tandcLink").live("click", function(e) {
       e.stopPropagation();
       e.preventDefault();
       window.open(this.href, "TandCWindow", "location=no,toolbar=no,directories=no,status=no,menubar=no,scrollbars=yes,resizable=yes,width=1024,height=600");
    });

    $(".sortPendingType").click(function() {
        var sort = $("#search_sort_form_ascending").val();
        sort = 'true';
        $("#search_sort_form_ascending").val(sort);
        $("#search_sort_form_sortby").val($(this).attr("href"));
        $("#search_sort_form").submit();
        return false;
    });

    // Do we need to display comments counts?
    if ($(".showCommentsCounts").length > 0) {
        var arrLen = 0,
            cmtHtml = "",
            commentUrl = "",
            currItem,
            currCount,
            currTitle,
            dataStr = "",
            i = 0,
            idArr = [],
            idList = "",
            mStr = "",
            respLen = 0,
            tmp = 0;
        if ($(".ahahTocArticles").length) {
            idList = $(this).find("input[name='articleIds']").val();
            if (idList) {
                idArr = idList.split(",");
                arrLen = idArr.length;
                for (i = 0; i < arrLen; i++) {
                    dataStr += "itemId=" + idArr[i] + "&";
                }
                commentUrl = hiddenContext + "/commenting/comments/jsoncommentscount.action";
                $.ajax({
                    type: "POST",
                    url: commentUrl,
                    data: dataStr,
                    success: function(resp, statusText) {
                        if (resp) {
                            respLen = resp.length;
                            for (i = 0; i < respLen; i++) {
                                currCount = resp[i].cmtcount;
                                currItem = resp[i].itemId;
                                if (currCount > 0) {
                                    // Split the itemId
                                    tmp = currItem.indexOf("/content");
                                    if (tmp !== -1) {
                                        mStr = hiddenContext + currItem.substr(tmp);
                                        $(".articleTitle").each(function(index) {
                                            currTitle = $(this);
                                            if (currTitle.find("a").attr("href") === mStr) {
                                                cmtHtml = "";
                                                cmtHtml += "<span class='bookmark-separator'>";
                                                cmtHtml += "<img src='/images/aip/icons_separator.png' width='2' height='16' />";
                                                cmtHtml += "</span><img src='/images/aip/comment_icon_display.png' alt='' />";
                                                cmtHtml += "<span class='commentCount'>(" + currCount + ")</span>";
                                                currTitle.append(cmtHtml).hide().fadeIn(750);
                                           }
                                        });
                                    }
                                }
                            }
                        }
                    },
                    error: function(req, statusText) {
                        if (consoleOK) {console.log("showCommentsCount(): Error '" + statusText + "'...");}
                    }
                });
            }
        }
    }

    $("#related a").click(function() {
      if ($("#hiddenmorelikethisidsforclick").size() > 0) {
        var morelikethisurl = $("#hiddenContext").text() + "/search/morelikethis",
            pubrelatedcontentids = $("#hiddenmorelikethisidsforclick").text(),
            webid = $("#hiddenmorelikethiswebid").text(),
            fields = $("#hiddenmorelikethisfields").text(),
            restrictions = $("#hiddenmorelikethisrestrictions").text(),
            number = $("#hiddenmorelikethisnumber").text(),
            numbershown = $("#hiddenmorelikethisnumbershown").text(),
            data = {
                "pubrelatedcontentids": pubrelatedcontentids,
                "webid": webid,
                "fields": fields,
                "restrictions": restrictions,
                "number": number,
                "numbershown": numbershown
            };

        $.ajax({
            type: "POST",
            url: morelikethisurl,
            data: data,
            dataType: "text",
            success: function(resp) {
                var target = $("#morelikethiscontent").get(0);
                target.innerHTML = resp;
                MathJax.Hub.Queue(["Typeset", MathJax.Hub, target]);
                $(".morelikethisloading").remove();
                $("#hiddenmorelikethisidsforclick").remove();
            }
        });
      }

    });

    return false;

});
